@@ -1,6 +1,6 @@
 package Lemonldap::NG::Manager::Api::Providers::SamlSp;
 
-our $VERSION = '2.0.10';
+our $VERSION = '2.19.0';
 
 package Lemonldap::NG::Manager::Api;
 
@@ -316,7 +316,8 @@ sub _getSamlSpByEntityId {
 sub _readSamlSpEntityId {
     my ( $self, $metadata ) = @_;
 
-    return ( $metadata =~ /entityID=['"](.+?)['"]/ ) ? $1 : undef;
+    my ($entityID) = $metadata =~ /entityID=['"](.+?)['"]/;
+    return $entityID;
 }
 
 sub _readSamlSpExportedAttributes {
@@ -383,7 +384,7 @@ sub _pushSamlSp {
         foreach ( keys %{ $push->{options} } ) {
             my $optionName = $self->_translateOptionApiToConf( $_, 'samlSP' );
             my $optionValue =
-              $self->_translateValueApiToConf( $_, $push->{options}->{$_} );
+              $self->_translateValueApiToConf( $optionName, $push->{options}->{$_} );
             $translatedOptions->{$optionName} = $optionValue;
         }
 
